(*
% File     : MGT034+2 : ILTP v1.1.2
% Domain   : Management (Organisation Theory)
% Problem  : Selection favors FMs above EPs until critical point reached
% Version  : [PM93] axioms.
% English  : Selection favors first movers above efficient producers past 
%            the appearance of efficient producers until the critical
%            point is reached. 
% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [PB+94] Peli et al. (1994), A Logical Approach to Formalizing
% Source   : [PM93]
% Names    : THEOREM 3 [PM93]
%          : T3 [PB+94]
% Status   : Theorem
% Status (intuit.) : Open
% Rating (intuit.) : 1.00 v1.0.0
% Rating (intuit.) : 1.00 v1.1
% Syntax   : Number of formulae    :   21 (   0 unit)
%            Number of atoms       :   80 (   2 equality)
%            Maximal formula depth :   10 (   6 average)
%            Number of connectives :   63 (   4 ~  ;   1  |;  35  &)
%                                         (   3 <=>;  20 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-4 arity)
%            Number of functors    :   11 (   3 constant; 0-2 arity)
%            Number of variables   :   43 (   0 singleton;  43 !;   0 ?)
%            Maximal term depth    :    3 (   1 average)
% Comments : 
*)

From Hammer Require Import Tactics.

Section FOFProblem.

Variable Universe : Set.
Variable UniverseElement : Universe.

Variable subpopulations_ : Universe -> Universe -> Universe -> Universe -> Prop.
Variable selection_favors_ : Universe -> Universe -> Universe -> Prop.
Variable in_environment_ : Universe -> Universe -> Prop.
Variable greater_or_equal_ : Universe -> Universe -> Prop.
Variable greater_ : Universe -> Universe -> Prop.
Variable environment_ : Universe -> Prop.
Variable decreases_ : Universe -> Prop.

Variable zero_ : Universe.
Variable start_time_ : Universe -> Universe.
Variable growth_rate_ : Universe -> Universe -> Universe.
Variable founding_rate_ : Universe -> Universe -> Universe.
Variable first_movers_ : Universe.
Variable efficient_producers_ : Universe.
Variable disbanding_rate_ : Universe -> Universe -> Universe.
Variable difference_ : Universe -> Universe -> Universe.
Variable critical_point_ : Universe -> Universe.
Variable cardinality_at_time_ : Universe -> Universe -> Universe.
Variable appear_ : Universe -> Universe -> Universe.

Variable mp1_high_growth_rates_1 : (forall E S1 S2 T : Universe, ((environment_ E /\ (subpopulations_ S1 S2 E T /\ greater_ (growth_rate_ S2 T) (growth_rate_ S1 T))) -> selection_favors_ S2 S1 T)).
Variable l3_2 : (forall E T : Universe, ((environment_ E /\ subpopulations_ first_movers_ efficient_producers_ E T) -> ~(decreases_ (difference_ (disbanding_rate_ first_movers_ T) (disbanding_rate_ efficient_producers_ T))))).
Variable mp_critical_point_means_FM_and_EP_3 : (forall E : Universe, ((environment_ E /\ in_environment_ E (critical_point_ E)) -> subpopulations_ first_movers_ efficient_producers_ E (critical_point_ E))).
Variable mp_FM_and_EP_when_EP_appears_4 : (forall E : Universe, ((environment_ E /\ in_environment_ E (appear_ efficient_producers_ E)) -> subpopulations_ first_movers_ efficient_producers_ E (appear_ efficient_producers_ E))).
Variable mp_difference_between_founding_rates_5 : (forall T : Universe, ((decreases_ (difference_ (founding_rate_ first_movers_ T) (founding_rate_ efficient_producers_ T)) /\ ~(decreases_ (difference_ (disbanding_rate_ first_movers_ T) (disbanding_rate_ efficient_producers_ T)))) -> decreases_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)))).
Variable mp_decreasing_function_6 : (forall E T To : Universe, ((environment_ E /\ (in_environment_ E To /\ (greater_or_equal_ (difference_ (growth_rate_ first_movers_ To) (growth_rate_ efficient_producers_ To)) zero_ /\ (greater_or_equal_ T (appear_ efficient_producers_ E) /\ greater_ To T)))) -> (decreases_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)) -> greater_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)) zero_))).
Variable mp_negative_growth_rate_difference_7 : (forall T : Universe, (greater_ zero_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)) <-> greater_ (growth_rate_ efficient_producers_ T) (growth_rate_ first_movers_ T))).
Variable mp_positive_growth_rate_difference_8 : (forall T : Universe, (greater_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)) zero_ <-> greater_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T))).
Variable mp_durations_are_time_intervals_9 : (forall E T1 T2 T : Universe, ((environment_ E /\ (in_environment_ E T1 /\ (in_environment_ E T2 /\ (greater_or_equal_ T2 T /\ greater_or_equal_ T T1)))) -> in_environment_ E T)).
Variable mp_opening_time_in_duration_10 : (forall E : Universe, (environment_ E -> in_environment_ E (start_time_ E))).
Variable mp_no_FM_before_opening_11 : (forall E : Universe, (environment_ E -> greater_or_equal_ (appear_ first_movers_ E) (start_time_ E))).
Variable mp_critical_time_points_12 : (forall E T : Universe, ((environment_ E /\ (in_environment_ E (critical_point_ E) /\ (greater_or_equal_ T (appear_ efficient_producers_ E) /\ greater_ (critical_point_ E) T))) -> in_environment_ E T)).
Variable mp_contains_FM_and_EP_13 : (forall E T : Universe, ((environment_ E /\ (in_environment_ E T /\ (greater_ (cardinality_at_time_ first_movers_ T) zero_ /\ greater_ (cardinality_at_time_ efficient_producers_ T) zero_))) -> subpopulations_ first_movers_ efficient_producers_ E T)).
Variable mp_symmetry_of_subpopulations_14 : (forall E T : Universe, ((environment_ E /\ subpopulations_ first_movers_ efficient_producers_ E T) -> subpopulations_ efficient_producers_ first_movers_ E T)).
Variable mp_FM_and_EP_members_EP_appeared_15 : (forall E T : Universe, ((environment_ E /\ subpopulations_ first_movers_ efficient_producers_ E T) -> greater_or_equal_ T (appear_ efficient_producers_ E))).
Variable mp_greater_or_equal_16 : (forall X Y : Universe, (greater_or_equal_ X Y <-> (greater_ X Y \/ X = Y))).
Variable mp_relationship_of_growth_rates_17 : (forall E T : Universe, ((environment_ E /\ (subpopulations_ first_movers_ efficient_producers_ E T /\ ~(greater_ zero_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T))))) -> greater_or_equal_ (difference_ (growth_rate_ first_movers_ T) (growth_rate_ efficient_producers_ T)) zero_)).
Variable d1_18 : (forall E Tc : Universe, ((environment_ E /\ Tc = (critical_point_ E)) -> (~(greater_ (growth_rate_ efficient_producers_ Tc) (growth_rate_ first_movers_ Tc)) /\ (forall T : Universe, ((subpopulations_ first_movers_ efficient_producers_ E T /\ greater_ T Tc) -> greater_ (growth_rate_ efficient_producers_ T) (growth_rate_ first_movers_ T)))))).
Variable a10_19 : (forall E T1 T2 T : Universe, ((environment_ E /\ (subpopulations_ first_movers_ efficient_producers_ E T1 /\ (subpopulations_ first_movers_ efficient_producers_ E T2 /\ (greater_or_equal_ T T1 /\ greater_or_equal_ T2 T)))) -> subpopulations_ first_movers_ efficient_producers_ E T)).
Variable a12_20 : (forall E T : Universe, ((environment_ E /\ subpopulations_ first_movers_ efficient_producers_ E T) -> decreases_ (difference_ (founding_rate_ first_movers_ T) (founding_rate_ efficient_producers_ T)))).

Theorem prove_t3_21 : (forall E T : Universe, ((environment_ E /\ (in_environment_ E (critical_point_ E) /\ (greater_or_equal_ T (appear_ efficient_producers_ E) /\ greater_ (critical_point_ E) T))) -> selection_favors_ first_movers_ efficient_producers_ T)).
Proof.
  time hprover.
Qed.

End FOFProblem.
