(*
% File     : SYJ201+1.010 : ILTP v1.1.2
% Domain   : Intuitionistic Syntactic
% Problem  : de Bruijn's example
% Version  : Especial.
%            Problem formulation : Intuit. Valid  Size 10
% English  : LHS(2*N+1) => RHS(2*N+1) with
%            RHS(m) = &&_{i=1..m} p(i),
%            LHS(m) = &&_{i=1..m} ((p(i)<=>p(i+1)) => c(N))
%            where addition is computed modulo m, and with
%            c(N) = &&_{i=1..N} p(i)
% Refs     : [Dyc97] Roy Dyckhoff. Some benchmark formulas for
%                    intuitionistic propositional logic. At
%                    http://www.dcs.st-and.ac.uk/~rd/logic/marks.html
%          :         de Bruijn, N.: personal communication in about 1990.
% Source   : [Dyc97]
% Names    : debruijn_p10 : Dyckhoff's benchmark formulas (1997)
% Status (intuit.) : Theorem
% Rating (intuit.) : 0.00 v1.0.0
% Comments : quite a tough exercise for students to prove by natural
%             deduction [Dyc97]
*)

From Hammer Require Import Tactics.

Section FOFProblem.

Variable Universe : Set.
Variable UniverseElement : Universe.

Variable p9_ : Prop.
Variable p8_ : Prop.
Variable p7_ : Prop.
Variable p6_ : Prop.
Variable p5_ : Prop.
Variable p4_ : Prop.
Variable p3_ : Prop.
Variable p21_ : Prop.
Variable p20_ : Prop.
Variable p2_ : Prop.
Variable p19_ : Prop.
Variable p18_ : Prop.
Variable p17_ : Prop.
Variable p16_ : Prop.
Variable p15_ : Prop.
Variable p14_ : Prop.
Variable p13_ : Prop.
Variable p12_ : Prop.
Variable p11_ : Prop.
Variable p10_ : Prop.
Variable p1_ : Prop.


Variable axiom1_1 : ((p1_ <-> p2_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom2_2 : ((p2_ <-> p3_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom3_3 : ((p3_ <-> p4_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom4_4 : ((p4_ <-> p5_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom5_5 : ((p5_ <-> p6_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom6_6 : ((p6_ <-> p7_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom7_7 : ((p7_ <-> p8_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom8_8 : ((p8_ <-> p9_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom9_9 : ((p9_ <-> p10_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom10_10 : ((p10_ <-> p11_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom11_11 : ((p11_ <-> p12_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom12_12 : ((p12_ <-> p13_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom13_13 : ((p13_ <-> p14_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom14_14 : ((p14_ <-> p15_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom15_15 : ((p15_ <-> p16_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom16_16 : ((p16_ <-> p17_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom17_17 : ((p17_ <-> p18_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom18_18 : ((p18_ <-> p19_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom19_19 : ((p19_ <-> p20_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom20_20 : ((p20_ <-> p21_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).
Variable axiom21_21 : ((p21_ <-> p1_) -> (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_))))))))))))))))))))).

Theorem con_22 : (p1_ /\ (p2_ /\ (p3_ /\ (p4_ /\ (p5_ /\ (p6_ /\ (p7_ /\ (p8_ /\ (p9_ /\ (p10_ /\ (p11_ /\ (p12_ /\ (p13_ /\ (p14_ /\ (p15_ /\ (p16_ /\ (p17_ /\ (p18_ /\ (p19_ /\ (p20_ /\ p21_)))))))))))))))))))).
Proof.
  time hprover.
Qed.

End FOFProblem.
